from typing import TYPE_CHECKING

if not TYPE_CHECKING:
    import cesloi.event.messages
    import cesloi.event.test
    import cesloi.event.mirai
    import cesloi.event.lifecycle
